package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ss.cardGetRecords.domain.CardGetRecords;
import com.ruoyi.ss.cardGetRecords.domain.CardGetRecordsVO;
import com.ruoyi.ss.cardGetRecords.domain.CardGetRecordsQuery;
import com.ruoyi.ss.cardGetRecords.service.ICardGetRecordsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 卡券领取（购买）记录Controller
 *
 * @author qzz
 * @date 2025-03-19
 */
@RestController
@RequestMapping("/system/getRecords")
public class CardGetRecordsController extends BaseController
{
    @Autowired
    private ICardGetRecordsService cardGetRecordsService;

    /**
     * 查询卡券领取（购买）记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:getRecords:list')")
    @GetMapping("/list")
    public TableDataInfo list(CardGetRecordsQuery query)
    {
        startPage();
        startOrderBy();
        List<CardGetRecordsVO> list = cardGetRecordsService.selectCardGetRecordsList(query);
        return getDataTable(list);
    }

    /**
     * 导出卡券领取（购买）记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:getRecords:export')")
    @Log(title = "卡券领取（购买）记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CardGetRecordsQuery query)
    {
        List<CardGetRecordsVO> list = cardGetRecordsService.selectCardGetRecordsList(query);
        ExcelUtil<CardGetRecordsVO> util = new ExcelUtil<CardGetRecordsVO>(CardGetRecordsVO.class);
        util.exportExcel(response, list, "卡券领取（购买）记录数据");
    }

    /**
     * 获取卡券领取（购买）记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:getRecords:query')")
    @GetMapping(value = "/{recordId}")
    public AjaxResult getInfo(@PathVariable("recordId") Long recordId)
    {
        return success(cardGetRecordsService.selectCardGetRecordsByRecordId(recordId));
    }

    /**
     * 新增卡券领取（购买）记录
     */
    @PreAuthorize("@ss.hasPermi('system:getRecords:add')")
    @Log(title = "卡券领取（购买）记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CardGetRecords cardGetRecords)
    {
        return toAjax(cardGetRecordsService.insertCardGetRecords(cardGetRecords));
    }

    /**
     * 修改卡券领取（购买）记录
     */
    @PreAuthorize("@ss.hasPermi('system:getRecords:edit')")
    @Log(title = "卡券领取（购买）记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CardGetRecords cardGetRecords)
    {
        return toAjax(cardGetRecordsService.updateCardGetRecords(cardGetRecords));
    }

    /**
     * 删除卡券领取（购买）记录
     */
    @PreAuthorize("@ss.hasPermi('system:getRecords:remove')")
    @Log(title = "卡券领取（购买）记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{recordIds}")
    public AjaxResult remove(@PathVariable Long[] recordIds)
    {
        return toAjax(cardGetRecordsService.deleteCardGetRecordsByRecordIds(recordIds));
    }
}
