package com.ruoyi.ss.cardGetRecords.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ss.cardGetRecords.mapper.CardGetRecordsMapper;
import com.ruoyi.ss.cardGetRecords.domain.CardGetRecords;
import com.ruoyi.ss.cardGetRecords.domain.CardGetRecordsVO;
import com.ruoyi.ss.cardGetRecords.domain.CardGetRecordsQuery;
import com.ruoyi.ss.cardGetRecords.service.ICardGetRecordsService;

import static com.ruoyi.common.constant.ServiceConstants.CARD_STATUS_UNUSED;

/**
 * 卡券领取（购买）记录Service业务层处理
 *
 * @author qzz
 * @date 2025-03-19
 */
@Service
public class CardGetRecordsServiceImpl implements ICardGetRecordsService
{
    @Autowired
    private CardGetRecordsMapper cardGetRecordsMapper;

    /**
     * 查询卡券领取（购买）记录
     *
     * @param recordId 卡券领取（购买）记录主键
     * @return 卡券领取（购买）记录
     */
    @Override
    public CardGetRecordsVO selectCardGetRecordsByRecordId(Long recordId)
    {
        return cardGetRecordsMapper.selectCardGetRecordsByRecordId(recordId);
    }

    /**
     * 查询卡券领取（购买）记录列表
     *
     * @param cardGetRecords 卡券领取（购买）记录
     * @return 卡券领取（购买）记录
     */
    @Override
    public List<CardGetRecordsVO> selectCardGetRecordsList(CardGetRecordsQuery cardGetRecords)
    {
        return cardGetRecordsMapper.selectCardGetRecordsList(cardGetRecords);
    }

    /**
     * 新增卡券领取（购买）记录
     *
     * @param cardGetRecords 卡券领取（购买）记录
     * @return 结果
     */
    @Override
    public int insertCardGetRecords(CardGetRecords cardGetRecords)
    {
        return cardGetRecordsMapper.insertCardGetRecords(cardGetRecords);
    }

    /**
     * 修改卡券领取（购买）记录
     *
     * @param cardGetRecords 卡券领取（购买）记录
     * @return 结果
     */
    @Override
    public int updateCardGetRecords(CardGetRecords cardGetRecords)
    {
        return cardGetRecordsMapper.updateCardGetRecords(cardGetRecords);
    }

    /**
     * 批量删除卡券领取（购买）记录
     *
     * @param recordIds 需要删除的卡券领取（购买）记录主键
     * @return 结果
     */
    @Override
    public int deleteCardGetRecordsByRecordIds(Long[] recordIds)
    {
        return cardGetRecordsMapper.deleteCardGetRecordsByRecordIds(recordIds);
    }

    /**
     * 删除卡券领取（购买）记录信息
     *
     * @param recordId 卡券领取（购买）记录主键
     * @return 结果
     */
    @Override
    public int deleteCardGetRecordsByRecordId(Long recordId)
    {
        return cardGetRecordsMapper.deleteCardGetRecordsByRecordId(recordId);
    }

    /**
     * 获取用户可用卡券
     */
    @Override
    public List<CardGetRecordsVO> getAvailableCard(Long userId) {
        CardGetRecordsQuery cardGetRecordsQuery = new CardGetRecordsQuery();
        cardGetRecordsQuery.setUserId(userId);
        cardGetRecordsQuery.setStatus(CARD_STATUS_UNUSED);
        return cardGetRecordsMapper.selectCardGetRecordsList(cardGetRecordsQuery);
    }
}
